abacusai.app_user_group_sign_in_token — AbacusAI documentation

# abacusai.app_user_group_sign_in_token

## Classes

`AppUserGroupSignInToken` | User Group Sign In Token

## Module Contents

class abacusai.app_user_group_sign_in_token.AppUserGroupSignInToken(client, token=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  User Group Sign In Token

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - token (str) – The token to sign in the user

  token
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict